This function loads a dataframe as input and returns a dataframe containing the mean values and mean standard deviations of Delta C and Delta V.
Details
Delta C and Delta V are rhythm metrics based on Ramus, F., Nespor, M., & Mehler, J. (1999). Correlates of linguistic rhythm in the speech signal. Cognition, 73(3), 265-292.
Delta C: SD of total C duration
Delta V: SD of total V duration
Author
Cong Zhang, cong.zhang@newcastle.ac.uk
Examples
df_test <- data.frame(cv_label = c("c", "v", "c", "v","c", "v", "c", "v"),
utterance_id = c("utt_1", "utt_1", "utt_2", "utt_2",
"utt_1", "utt_1", "utt_2", "utt_2"),
cv_duration = c(0.1, 0.8, 0.2, 0.5, 0.3, 0.3, 0.4, 0.7))
delta_cv(df_test, cv_label, utterance_id, cv_duration)
#> # A tibble: 2 × 3
#> cv_label mean_delta sd_delta
#> <chr> <dbl> <dbl>
#> 1 c 0.141 2.78e-17
#> 2 v 0.247 1.5 e- 1